@@ -11,7 +11,7 @@ class InterfaceNotFound(Exception):
 class ITemplatePluginMixin:
     """A mixin that be inherited from to build renderable plugins.
 
-    Use this in conjunction with :ref:`gdaps.templatetags:gdaps`
+    Use this in conjunction with the :ref:`render_plugin templatetag <template-support>`
     to build plugins that are renderable in templates.
     """
 
